@@ -10,7 +10,7 @@ function(data=NULL, predictions=NULL, minimize=T) {
     return(post(lapply(1:length(data$test), function(i) {
         sapply(1:nrow(data$test[[i]]), function(j) {
             perfs = subset(data$test[[i]][j,], T, data$performance)
-            as.numeric(abs(perfs[which(data$performance == predictions[[i]][j])] - optfun(perfs)))
+            as.numeric(abs(perfs[which(data$performance == predictions[[i]][[j]]$algorithm[1])] - optfun(perfs)))
             })
         })))
 }
